<?php 

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;
use \Doctrine\ORM\EntityManager;


class RelAliqProd {
    
	protected $entityManager; 

	public function __construct(EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}
	
	public function getAliqProdutos($conditions) {
        $params = $this->setParameters($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::REL_ALIQUOTA_PRODUTOS, $params);
    }
    
    public function getAliqProdutosEst($conditions) {
        $params = $this->setParameters($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::REL_ALIQUOTA_PRODUTOS_EST, $params);
    }

    public function getAliqProdutosCom($conditions) {
        $params = $this->setParameters($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::REL_ALIQUOTA_PRODUTOS_COM, $params);
    }
    
	private function setParameters($conditions) {
	    return array (
            ':NRORG'=> $conditions['NRORG'], 
            ':CDFILIAL'=>$conditions['CDFILIAL'],
            ':CDPRODLIST'=>$conditions['CDPRODLIST'], 
            ':TCDPRODUTO'=>$conditions['TCDPRODUTO'], 
            ':CDARVPRODF'=>$conditions['CDARVPRODF'], 
            ':CDARVPRODI'=>$conditions['CDARVPRODI'], 
            ':PRODNIV'=>$conditions['PRODNIV'],
            ':CDNVPRODUTO'=>$conditions['CDNVPRODUTO']
            );
	}
	
	const REL_ALIQUOTA_PRODUTOS_EST = "
    SELECT P.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO AS NMPRODUTOLABEL, AL.VRPEALIMPFIS, AL.CDIMPOSTO, NVL(AL.NMIMPOSTO, 'Sem Imposto') AS NMIMPOSTO, AL.VRALIQIBPT, P.CDPRODINTE
      FROM PRODUTO P
      LEFT JOIN (SELECT I.NMIMPOSTO, A.VRALIQIBPT, A.CDPRODUTO, A.NRORG, A.CDIMPOSTO, A.VRPEALIMPFIS
                   FROM ALIQIMPFIS A
              LEFT JOIN IMPOSTO I
                     ON A.CDIMPOSTO = I.CDIMPOSTO
                    AND A.NRORG = I.NRORG
                  WHERE A.CDFILIAL = :CDFILIAL
                    AND A.NRORG = :NRORG 
                 ) AL 
          ON P.CDPRODUTO = AL.CDPRODUTO 
         AND P.NRORG = AL.NRORG
       WHERE (((INSTR(:CDPRODLIST, P.CDPRODUTO) > 0 ) OR (P.CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF ) OR (P.CDARVPROD LIKE :PRODNIV)) OR (:TCDPRODUTO = 'T'))
         AND P.NRORG = :NRORG
         AND P.CDPRODUTO = P.CDPRODESTO
         AND P.CDNVPRODUTO = :CDNVPRODUTO
        ORDER BY P.CDARVPROD
    ";
    
    
    const REL_ALIQUOTA_PRODUTOS_COM = "
      SELECT P.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO AS NMPRODUTOLABEL, AL.VRPEALIMPFIS, AL.CDIMPOSTO, NVL(AL.NMIMPOSTO, 'Sem Imposto') AS NMIMPOSTO, AL.VRALIQIBPT, P.CDPRODINTE
        FROM PRODUTO P
        LEFT JOIN (SELECT I.NMIMPOSTO, A.VRALIQIBPT, A.CDPRODUTO, A.NRORG, A.CDIMPOSTO, A.VRPEALIMPFIS
                     FROM ALIQIMPFIS A
                LEFT JOIN IMPOSTO I
                       ON A.CDIMPOSTO = I.CDIMPOSTO
                      AND A.NRORG = I.NRORG
                    WHERE A.CDFILIAL = :CDFILIAL
                      AND A.NRORG = :NRORG 
                   ) AL 
            ON P.CDPRODUTO = AL.CDPRODUTO 
           AND P.NRORG = AL.NRORG
         WHERE (((INSTR(:CDPRODLIST, P.CDPRODUTO) > 0 ) OR (P.CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF ) OR (P.CDARVPROD LIKE :PRODNIV)) OR (:TCDPRODUTO = 'T'))
           AND P.NRORG = :NRORG
           AND P.CDPRODUTO <> P.CDPRODESTO
           AND P.CDNVPRODUTO = :CDNVPRODUTO
        ORDER BY P.CDARVPROD
    ";
    
    
    const REL_ALIQUOTA_PRODUTOS = "
        SELECT P.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO AS NMPRODUTOLABEL, AL.VRPEALIMPFIS, AL.CDIMPOSTO, NVL(AL.NMIMPOSTO, 'Sem Imposto') AS NMIMPOSTO, AL.VRALIQIBPT, P.CDPRODINTE
          FROM PRODUTO P
          LEFT JOIN (SELECT I.NMIMPOSTO, A.VRALIQIBPT, A.CDPRODUTO, A.NRORG, A.CDIMPOSTO, A.VRPEALIMPFIS
                       FROM ALIQIMPFIS A
                  LEFT JOIN IMPOSTO I
                         ON A.CDIMPOSTO = I.CDIMPOSTO
                        AND A.NRORG = I.NRORG
                      WHERE A.CDFILIAL = :CDFILIAL
                        AND A.NRORG = :NRORG 
                    ) AL 
            ON P.CDPRODUTO = AL.CDPRODUTO 
           AND P.NRORG = AL.NRORG
          WHERE (((INSTR(:CDPRODLIST, P.CDPRODUTO) > 0) OR (P.CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF ) OR (P.CDARVPROD LIKE :PRODNIV)) OR (:TCDPRODUTO = 'T'))
            AND P.NRORG = :NRORG   
            AND P.CDNVPRODUTO = :CDNVPRODUTO
        ORDER BY P.CDARVPROD
    ";
}